//----------------------------------------------------------------
//
// OpenDCC - DCC Sniffer
//
// This source file is subject of the GNU general public license 2,
// that is available at the world-wide-web at
// http://www.gnu.org/licenses/gpl.txt
//
//-----------------------------------------------------------------
//
// file:      hardware.h
// author:    Wolfgang Kufer
// contact:   kufer@gmx.de
// history:   2008-04-02 V0.01 kw start
//
//-----------------------------------------------------------------
//
// purpose:   log of DCC and forward to host
// content:   all hardware project settings are done here!!
//            
//            1.   Prozessor, Timing
//                 (change here, if a different uP is used)
//            2.   IOs
//                 (change here, if run on a different board)
//
//-----------------------------------------------------------------
#ifndef __HARDWARE_H__
#define __HARDWARE_H__


//========================================================================
// 1. Processor Definitions
//========================================================================
//
#define  ATMEGA162      0
#define  ATMEGA8515     1

#define  PROCESSOR     ATMEGA162           // or ATMEGA8515
// if changed: check timings, timer settings, baudrate

#if (PROCESSOR == ATMEGA162)
  // atmega162:   2kByte SRAM, 1kByte EEPROM
  #define SRAM_SIZE    2048
  #define EEPROM_SIZE  1024
  #define EEPROM_BASE  0x810000L
#endif

#if (PROCESSOR == ATMEGA8515)
  // atmega8515:   4kByte SRAM, 2kByte EEPROM
  #define SRAM_SIZE    4096
  #define EEPROM_SIZE  2048
  #define EEPROM_BASE  0x810000L
#endif
//
#ifndef F_CPU
// prevent compiler error by supplying a default 
# warning "F_CPU not defined for <config.h>", set default to 16MHz 
# define F_CPU 16000000UL
// if changed: check every place where it is used 
// (possible range overflow in preprocessor!)
#endif

//------------------------------------------------------------------------
// Fuses of ATmega162 (just for documentation)
//------------------------------------------------------------------------

//========================================================================
// 2. Port Definitions
//========================================================================


// --------    PORTA (LEDs)

#define LED_PROG     0     // program   - yellow
#define LED_RAILCOM  1     // railcom   - yellow
#define LED_ACC      2     // accessory - green
#define LED_LOCO     3     // loco      - green
#define LED_GO       4     // sniffing  - blue
#define LED_ON       5     // on        - green
                           // A6 not connected
                           // A7 not connected

//LED prg (orange)
#define                LED_PROG_OFF           PORTA &= ~(1<<LED_PROG)
#define                LED_PROG_ON            PORTA |= (1<<LED_PROG)
#define                LED_PROG_TOGGLE        PORTA ^= (1<<LED_PROG)
//LED railcom (orange)
#define                LED_RAILCOM_OFF        PORTA &= ~(1<<LED_RAILCOM)
#define                LED_RAILCOM_ON         PORTA |= (1<<LED_RAILCOM)
#define                LED_RAILCOM_TOGGLE     PORTA ^= (1<<LED_RAILCOM)
//LED acc (green)
#define                LED_ACC_OFF            PORTA &= ~(1<<LED_ACC)
#define                LED_ACC_ON             PORTA |= (1<<LED_ACC)
#define                LED_ACC_TOGGLE         PORTA ^= (1<<LED_ACC)
//LED loco (green)
#define                LED_LOCO_OFF           PORTA &= ~(1<<LED_LOCO)
#define                LED_LOCO_ON            PORTA |= (1<<LED_LOCO)
#define                LED_LOCO_TOGGLE        PORTA ^= (1<<LED_LOCO)
//LED go (blue)
#define                LED_GO_OFF             PORTA &= ~(1<<LED_GO)
#define                LED_GO_ON              PORTA |= (1<<LED_GO)
#define                LED_GO_TOGGLE          PORTA ^= (1<<LED_GO)
//LED on (green)
#define                LED_ON_OFF             PORTA &= ~(1<<LED_ON)
#define                LED_ON_ON              PORTA |= (1<<LED_ON)
#define                LED_ON_TOGGLE          PORTA ^= (1<<LED_ON)

// --------    PORTB
                           // B0 not connected
#define RC_LOWPASS_OUT 1   // B1 pwm for rc lowpass
#define A_THRESHOLD    2   // B2 either threshold or RXD1
#define A_CAPTURE      3   // B3 either capture or TXD1
                           // B4 not connected
#define MOSI           5
#define MISO           6
#define SCK            7

// --------    PORTC

#define TRIGGER_PORT   PINC
#define TRIGGER        0     // in
#define SPARE          2     // on 6-pin header


// --------    PORTD

#define MY_RXD         0     // in
#define MY_TXD         1     // out
#define DCC_IN         2     // in (Int 0)
#define MY_RTS         3     // in
#define KEY            4     // in (pullup)
#define MY_CTS         5     // out
#define SJUMPER7       6     // in (pullup)
#define SJUMPER8       7     // in (pullup)

// RTS is aktive low
#define MY_RTS_DETECT    (!(PIND & (1<<MY_RTS)))

#define MY_CTS_HIGH      PORTD |= (1<<MY_CTS)
#define MY_CTS_LOW       PORTD &= ~(1<<MY_CTS)
#define MY_CTS_STATE     (PORTD & (1<<MY_CTS))

#define KEY_PRESSED      (!(PIND & (1<<KEY)))

// satisfy keyboard.c
#define KEY_PORT           PIND
#define KEY_MASK           (1<<KEY)         // the keyboard task runs only on
                                            // those ports defined in the mask
                                            // Ports not in the mask are ignored
#define KEY_OFFSET         0                // shift keystroke result with this number


// --------    PORTE

#define D_CAPTURE      0   // (in) (INT2)


#endif   // hardware.h

