#//------------------------------------------------------------------------
//
// OpenDCC - DCC Sniffer
//
// Copyright (c) 2007 Kufer
//
// This source file is subject of the GNU general public license 2,
// that is available at the world-wide-web at
// http://www.gnu.org/licenses/gpl.txt
// 
//------------------------------------------------------------------------
//
// file:      tracker.h
// author:    Wolfgang Kufer
// contact:   kufer@gmx.de
// webpage:   http://www.opendcc.de
// history:   2008-03-01 V0.1 kw start
//         
//------------------------------------------------------------------------
//
// purpose:   flexible general purpose decoder for dcc
//            This is the central definition file for the project
//
//------------------------------------------------------------------------
//
// content:   2. EEPROM definitions (CV's)
//            3. Global variables
//            4. Useful inline routines (delay, Semaphor-operations)
//
//========================================================================
//
#ifndef _TRACKER_H_
#define _TRACKER_H_

//========================================================================
// 1. Project Definitions
//========================================================================
//
// 1.a) General
//
typedef struct
  {
    unsigned char bits;       // bitfield for active trackers
                                // bitfield:
                                //  0 use tracker 0
                                //  1 use tracker 1
                                //  2 use tracker 2
                                //  3 use tracker 3
                                //  7 track all
    unsigned int addr[4];     // the tracker
  } t_trackpara;

#define D_HEX    (1<<4)
#define D_TSTAMP (1<<5)
#define D_VERBOSE (1<<6)
#define D_VUMETER (1<<7)

#define D_ACTIVE   (1<<0)
#define D_INACTIVE (1<<1)

typedef struct
  {
    unsigned char KeyMode;        // Keyboard mode, bitfield:
                                  //  all 0: no Tracer logging
                                  //  Bit 0: logg only during key pressed
                                  //  Bit 1: key toggles Enable State
                                  //  Bit 2: reset timer
    unsigned char DisplayMode;    // Display, bitfield:
                                  //  Bits 0..2: HexMode (coded like NCE)
                                  //    0 Hex with leading special (see table 2) preamble char  	$03686B  	
                                  //    1 Hex same as H0 but with spaces between bytes 	$ 03 68 6B 	
                                  //    2 Hex with no preamble and no spaces 	03686B 	
                                  //    3 Hex with no preamble but with spaces between bytes 	03 68 6B 	
                                  //    4 Hex with preamble prefix 'P' but no spaces 	P0E03686B 	
                                  //    5 Hex same as H4 but with spaces between bytes 	P0E 03 68 6B 	
                                  //    6 Hex with 'P' prefix but no preamble count nor spaces 	P03686B 	
                                  //    7 Hex same as H4 but with spaces between bytes
                                  //  Bit 3: reserved
                                  //  Bit 4: Enable HexMode (D_HEX)
                                  //  Bit 5: Add Time Stamp (D_TSTAMP)
                                  //  Bit 6: Add Verbose String (D_VERBOSE)
                                  //  Bit 7: Add VU-Meter to verbose (D_VUMETER)
    unsigned char TrackTrigger;   // Show events on trigger input
                                  //  Bit 0: show activate events
                                  //  Bit 1: show deactivate events
    unsigned char TrackIdle;      // Idle
    unsigned char TrackSM;        // ServiceMode
    unsigned char TrackReset;     // Resets
    unsigned char TrackBiDi;        // Railcom Commands
    t_trackpara   TrackLocoSpeed;   // Loco Speed (up to 4 Trackers)
    t_trackpara   TrackLocoFunc;    // Loco Func (up to 4 Trackers)
    t_trackpara   TrackLocoPoM;     // Loco PoM (up to 4 Trackers)
    t_trackpara   TrackAcc;         // Accessory (up to 4 Trackers)
    t_trackpara   TrackExt;         // ExtAccessory
  } t_SnifferState;

extern t_SnifferState eeConfig EEMEM;

extern t_SnifferState SnifferState;

extern unsigned char EnableDisplay;

void toggle_EnableDisplay(void);

extern void load_states(void);

extern void save_state_changes(void);

extern void init_tracker(void);

extern void run_tracker(void);   // must be called in a loop


#endif   // _TRACKER_H_
